@@ -292,8 +292,8 @@ class SmartWeather:
                     "air_temp_low_color": row["air_temp_low_color"],
                     "precip": await cnv.precip(precip, UNIT_PRECIP_MM, self._to_units_precip),
                     "precip_probability": row["precip_probability"],
-                    "precip_icon": row["precip_icon"],
-                    "precip_type": row["precip_type"],
+                    "precip_icon": row.get("precip_icon", ""),
+                    "precip_type": row.get("precip_type", ""),
                     "wind_avg": await cnv.wind(sum_wind_avg, UNIT_WIND_MS, self._to_units_wind),
                     "wind_bearing": sum_wind_bearing,
                     "current_condition": current_condition,
@@ -318,8 +318,8 @@ class SmartWeather:
                     "relative_humidity": row["relative_humidity"],
                     "precip": await cnv.precip(row["precip"], UNIT_PRECIP_MM, self._to_units_precip),
                     "precip_probability": row["precip_probability"],
-                    "precip_icon": row["precip_icon"],
-                    "precip_type": row["precip_type"],
+                    "precip_icon": row.get("precip_icon", ""),
+                    "precip_type": row.get("precip_type", ""),
                     "wind_avg": await cnv.wind(row["wind_avg"], UNIT_WIND_MS, self._to_units_wind),
                     "wind_gust": await cnv.wind(row["wind_gust"], UNIT_WIND_MS, self._to_units_wind),
                     "wind_avg_color": row["wind_avg_color"],
@@ -360,14 +360,15 @@ class SmartWeather:
         except asyncio.TimeoutError:
             raise RequestError("Request to endpoint timed out: {endpoint}")
         except ClientError as err:
-            if err.message == "Unauthorized":
+            if "Unauthorized" in str(err):
                 raise InvalidApiKey("Your API Key is invalid or does not support this operation")
-            elif err.message == "Not Found":
+            elif "Not Found" in str(err):
                 raise ResultError("The Station ID does not exist")
             else:
                 raise RequestError(
                     f"Error requesting data from {endpoint}: {err}"
                 ) from None
+
         finally:
             if not use_running_session:
                 await session.close()
