@@ -199,6 +199,7 @@ class ForecastDataDaily:
 
     def __init__(self, data):
         self._timestamp = data["timestamp"]
+        self._epochtime = data["epochtime"]
         self._conditions = data["conditions"]
         self._icon = data["icon"]
         self._sunrise = data["sunrise"]
@@ -221,6 +222,11 @@ class ForecastDataDaily:
         """Forecast DateTime."""
         return self._timestamp.isoformat()
 
+    @property
+    def epochtime(self):
+        """Forecast Epoch Time."""
+        return self._epochtime
+
     @property
     def conditions(self) -> str:
         """Return condition text ."""
@@ -306,6 +312,7 @@ class ForecastDataHourly:
 
     def __init__(self, data):
         self._timestamp = data["timestamp"]
+        self._epochtime = data["epochtime"]
         self._conditions = data["conditions"]
         self._icon = data["icon"]
         self._temperature = data["air_temperature"]
@@ -332,6 +339,11 @@ class ForecastDataHourly:
         """Forecast DateTime."""
         return self._timestamp.isoformat()
 
+    @property
+    def epochtime(self):
+        """Forecast Epoch Time."""
+        return self._epochtime
+
     @property
     def conditions(self) -> str:
         """Return condition text ."""
